@@ -40,7 +40,6 @@ int kdx;
 int mdx;
 int lcl_sz;
 int nbr_sz;
-var_sct *var;
 RefAST tr;
 
  static int wlk_nbr; // Same as number of threads
@@ -92,7 +91,7 @@ RefAST tr;
    } 
    */
 #ifdef _OPENMP
-#pragma omp parallel for default(none) private(kdx,wlk_lcl,var,tr) shared(wlk_ptr,idx,nbr_sz,inn_vtr )
+#pragma omp parallel for default(none) private(kdx,wlk_lcl,tr) shared(wlk_ptr,idx,nbr_sz,inn_vtr )
 #endif
    for(kdx=0 ;kdx< nbr_sz; kdx++) {      
      wlk_lcl= wlk_ptr[omp_get_thread_num()];
@@ -129,7 +128,7 @@ int parse_antlr(std::vector<prs_cls> &prs_vtr,char *fl_spt_usr,char *cmd_ln_sng)
   
   const std::string fnc_nm("parse_antlr"); // [sng] Function name
   bool bExit=false;
-  int iret;
+  int rcd=0;
   int idx;
   int thd_nbr=(int)prs_vtr.size();  
   std::string filename(fl_spt_usr);
@@ -192,7 +191,7 @@ int parse_antlr(std::vector<prs_cls> &prs_vtr,char *fl_spt_usr,char *cmd_ln_sng)
 	t=t->getNextSibling();
       }
       dbg_prn(fnc_nm,"Parser tree printed");
-    } // endif dbg
+    } // !dbg
   }  
   
   catch (RecognitionException& pe) {
@@ -236,9 +235,9 @@ int parse_antlr(std::vector<prs_cls> &prs_vtr,char *fl_spt_usr,char *cmd_ln_sng)
     {
       bExit=true;
       // remember ExitEXception ONLY returns an int in a string
-      iret=atoi(strExit.getMessage().c_str());
+      rcd=atoi(strExit.getMessage().c_str());
       if(nco_dbg_lvl_get() >= nco_dbg_fl) 
-         cerr<<"Exit Exception "<<iret<< endl;
+         cerr << "Exit Exception " << rcd << endl;
     }
     catch(std::exception& e) 
     {
@@ -258,7 +257,7 @@ int parse_antlr(std::vector<prs_cls> &prs_vtr,char *fl_spt_usr,char *cmd_ln_sng)
   //(void)nco_free(filename);
   
   if(bExit)
-    return iret;
+    return rcd;
   else
     return 0;  
 
