@@ -355,6 +355,8 @@ main(int argc,char **argv)
     {"thr_nbr",required_argument,0,'t'},
     {"units",no_argument,0,'u'},
     {"variable",no_argument,0,'v'},
+    {"output_user_defined_variables",no_argument,0,'v'},
+    {"usr_dfn_var",no_argument,0,'v'},
     {"exclude",no_argument,0,'x'},
     {"xcl",no_argument,0,'x'},
     {0,0,0,0}
@@ -552,7 +554,7 @@ main(int argc,char **argv)
       xtr_nbr=0;
       break;
     case '?': /* Question mark means unrecognized option, print proper usage then EXIT_FAILURE */
-      (void)fprintf(stdout,"%s: ERROR in command-line syntax/options. Missing or unrecognized option. Please reformulate command accordingly.\n",nco_prg_nm_get());
+      (void)fprintf(stdout,"%s: ERROR in command-line syntax/options. Missing or unrecognized option. Please reformulate command or upgrade NCO as appropriate.\n",nco_prg_nm_get());
       (void)nco_usg_prn();
       nco_exit(EXIT_FAILURE);
       break;
@@ -560,7 +562,7 @@ main(int argc,char **argv)
       err_prn(fnc_nm,"Long options are not available in this build. Use single letter options instead.\n");
       break;
     default: /* Print proper usage */
-      (void)fprintf(stdout,"%s ERROR in command-line syntax/options. Please reformulate command accordingly.\n",nco_prg_nm_get());
+      (void)fprintf(stdout,"%s ERROR in command-line syntax/options. Please reformulate command or upgrade NCO as appropriate.\n",nco_prg_nm_get());
       (void)nco_usg_prn();
       nco_exit(EXIT_FAILURE);
       break;
@@ -1220,13 +1222,16 @@ main(int argc,char **argv)
     var_fix_out=(var_sct **)nco_free(var_fix_out);
   } /* !flg_mmr_cln */
   
-  // nco_exit_gracefully();
-  (void)fclose(stderr);
-  (void)fclose(stdin);
-  (void)fclose(stdout);
-  (void)nco_free(nco_prg_nm_get());
+  // 20231020: antlr_ret from ~/sw/aca/swn_prf.sh appears to be 133. Why?
+  //(void)fclose(stderr);
+  //(void)fclose(stdin);
+  //(void)fclose(stdout);
+  //(void)nco_free(nco_prg_nm_get());
+  //nco_exit(antlr_ret);
 
-  nco_exit(antlr_ret);
+  // 20231020: return() here just as with other NCO operators
+  nco_exit_gracefully();
+  return EXIT_SUCCESS;
 } /* !main() */
 
 // Copy vector elements
@@ -1288,7 +1293,6 @@ ram_vars_add
 
   var1=ncap_sclr_var_mk(std::string("NC_STRING"),nco_int(NC_STRING));
   prs_arg->ncap_var_write(var1,true);
-
 #endif // !ENABLE_NETCDF4
   
 #ifdef INFINITY
