@@ -424,8 +424,8 @@ main(int argc,char **argv)
     case '7': /* Request netCDF4-classic output storage format */
       fl_out_fmt=NC_FORMAT_NETCDF4_CLASSIC;
       break;
-    case 'A': /* Toggle FORCE_APPEND */
-      FORCE_APPEND=!FORCE_APPEND;
+    case 'A': /* Activate FORCE_APPEND */
+      FORCE_APPEND=True;
       break;
     case 'a': /* Re-order dimensions */
       dmn_rdr_lst_in=nco_lst_prs_2D(optarg,",",&dmn_rdr_nbr_in);
@@ -446,10 +446,10 @@ main(int argc,char **argv)
       lmt_nbr++;
       break;
     case 'F': /* Toggle index convention. Default is 0-based arrays (C-style). */
-      FORTRAN_IDX_CNV=!FORTRAN_IDX_CNV;
+      FORTRAN_IDX_CNV=True;
       break;
     case 'h': /* Toggle appending to history global attribute */
-      HISTORY_APPEND=!HISTORY_APPEND;
+      HISTORY_APPEND=False;
       break;
     case 'L': /* [enm] Deflate level. Default is 0. */
       dfl_lvl=(int)strtol(optarg,&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
@@ -462,8 +462,8 @@ main(int argc,char **argv)
       nco_pck_map_sng=(char *)strdup(optarg);
       nco_pck_map=nco_pck_map_get(nco_pck_map_sng);
       break;
-    case 'O': /* Toggle FORCE_OVERWRITE */
-      FORCE_OVERWRITE=!FORCE_OVERWRITE;
+    case 'O': /* Activate FORCE_OVERWRITE */
+      FORCE_OVERWRITE=True;
       break;
     case 'o': /* Name of output file */
       fl_out=(char *)strdup(optarg);
@@ -475,7 +475,7 @@ main(int argc,char **argv)
       fl_pth=(char *)strdup(optarg);
       break;
     case 'R': /* Toggle removal of remotely-retrieved-files. Default is True. */
-      RM_RMT_FL_PST_PRC=!RM_RMT_FL_PST_PRC;
+      RM_RMT_FL_PST_PRC=False;
       break;
     case 'r': /* Print CVS program information and copyright notice */
       (void)nco_vrs_prn(CVS_Id,CVS_Revision);
@@ -522,7 +522,7 @@ main(int argc,char **argv)
       nco_exit(EXIT_FAILURE);
       break;
     default: /* Print proper usage */
-      (void)fprintf(stdout,"%s ERROR in command-line syntax/options. Please reformulate command accordingly.\n",nco_prg_nm_get());
+      (void)fprintf(stdout,"%s ERROR in command-line syntax/options. Please reformulate command or upgrade NCO as appropriate.\n",nco_prg_nm_get());
       (void)nco_usg_prn();
       nco_exit(EXIT_FAILURE);
       break;
@@ -788,7 +788,7 @@ main(int argc,char **argv)
   
   /* NB: Much of following logic is required by netCDF constraint that only
      one record variable is allowed per file. netCDF4 will relax this constraint.
-     Hence making following logic prettier or funcionalizing is not high priority.
+     Hence making following logic prettier or functionalizing is not high priority.
      Logic may need to be simplified/re-written once netCDF4 is released. */
   if(REDEFINED_RECORD_DIMENSION){
     if(nco_dbg_lvl >= nco_dbg_std) (void)fprintf(fp_stdout,"%s: INFO Requested re-order will change record dimension from %s to %s. netCDF allows only one record dimension. Hence %s will make %s record (least rapidly varying) dimension in all variables that contain it.\n",nco_prg_nm,rec_dmn_nm_in,rec_dmn_nm_out,nco_prg_nm,rec_dmn_nm_out);
@@ -1039,11 +1039,11 @@ main(int argc,char **argv)
           lcl_nbr_var++;
           var_prc_out[idx]->id=msg_bfr[2];
           /* Process this variable same as UP code */
-#if 0
+#if false
 	  /* NB: Immediately preceding MPI else scope confounds Emacs indentation
 	     Fake end scope restores correct indentation, simplifies code-checking */
 	} /* fake end else */
-#endif /* !0 */
+#endif /* !false */
 #else /* !ENABLE_MPI */
 #ifdef _OPENMP
 #pragma omp parallel for default(none) private(idx,in_id) shared(aed_lst_add_fst,aed_lst_scl_fct,nco_dbg_lvl,dmn_idx_out_in,dmn_rdr_nbr,dmn_rvr_in,in_id_arr,nbr_var_prc,nco_pck_map,nco_pck_plc,out_id,nco_prg_nm,rcd,var_prc,var_prc_out)
