@@ -462,8 +462,8 @@ main(int argc,char **argv)
     case '7': /* Request netCDF4-classic output storage format */
       fl_out_fmt=NC_FORMAT_NETCDF4_CLASSIC;
       break;
-    case 'A': /* Toggle FORCE_APPEND */
-      FORCE_APPEND=!FORCE_APPEND;
+    case 'A': /* Activate FORCE_APPEND */
+      FORCE_APPEND=True;
       break;
     case 'C': /* Extract all coordinates associated with extracted variables? */
       EXTRACT_ASSOCIATED_COORDINATES=False;
@@ -480,13 +480,13 @@ main(int argc,char **argv)
       lmt_nbr++;
       break;
     case 'F': /* Toggle index convention. Default is 0-based arrays (C-style). */
-      FORTRAN_IDX_CNV=!FORTRAN_IDX_CNV;
+      FORTRAN_IDX_CNV=True;
       break;
     case 'H': /* Toggle writing input file list attribute */
-      FL_LST_IN_APPEND=!FL_LST_IN_APPEND;
+      FL_LST_IN_APPEND=False;
       break;
     case 'h': /* Toggle appending to history global attribute */
-      HISTORY_APPEND=!HISTORY_APPEND;
+      HISTORY_APPEND=False;
       break;
     case 'L': /* [enm] Deflate level. Default is 0. */
       dfl_lvl=(int)strtol(optarg,&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
@@ -503,8 +503,8 @@ main(int argc,char **argv)
 	nco_exit(EXIT_FAILURE);
       } /* end if */
       break;
-    case 'O': /* Toggle FORCE_OVERWRITE */
-      FORCE_OVERWRITE=!FORCE_OVERWRITE;
+    case 'O': /* Activate FORCE_OVERWRITE */
+      FORCE_OVERWRITE=True;
       break;
     case 'o': /* Name of output file */
       fl_out=(char *)strdup(optarg);
@@ -517,7 +517,7 @@ main(int argc,char **argv)
       nco_pck_plc=nco_pck_plc_get(nco_pck_plc_sng);
       break;
     case 'R': /* Toggle removal of remotely-retrieved-files. Default is True. */
-      RM_RMT_FL_PST_PRC=!RM_RMT_FL_PST_PRC;
+      RM_RMT_FL_PST_PRC=False;
       break;
     case 'r': /* Print CVS program information and copyright notice */
       (void)nco_vrs_prn(CVS_Id,CVS_Revision);
@@ -567,7 +567,7 @@ main(int argc,char **argv)
       nco_exit(EXIT_FAILURE);
       break;
     default: /* Print proper usage */
-      (void)fprintf(stdout,"%s ERROR in command-line syntax/options. Please reformulate command accordingly.\n",nco_prg_nm_get());
+      (void)fprintf(stdout,"%s ERROR in command-line syntax/options. Please reformulate command or upgrade NCO as appropriate.\n",nco_prg_nm_get());
       (void)nco_usg_prn();
       nco_exit(EXIT_FAILURE);
       break;
@@ -1169,7 +1169,7 @@ main(int argc,char **argv)
 #endif /* !ENABLE_MPI */
 	      /* Process all variables in current record */
 	      if(nco_dbg_lvl > nco_dbg_scl) (void)fprintf(stderr,gettext("Record %ld of %s is output record %ld\n"),idx_rec,fl_in,rec_usd_cml);
-#if 0
+#if false
 	      /* NB: Immediately preceding MPI for scope confounds Emacs indentation
 		 Fake end scope restores correct indentation, simplifies code-checking */
 	    } /* fake end for */
@@ -1339,7 +1339,7 @@ main(int argc,char **argv)
       if(prc_rnk != rnk_mgr){ /* Only workers have indices of variables to process */
 	for(jdx=0;jdx<lcl_nbr_var;jdx++){
 	  idx=lcl_idx_lst[jdx];
-#if 0
+#if false
 	  /* NB: Immediately preceding MPI if/for scopes confound Emacs indentation
 	     Fake end scopes restore correct indentation, simplify code-checking */
 	} /* fake end for */
@@ -1527,7 +1527,7 @@ main(int argc,char **argv)
     var_fix=(var_sct **)nco_free(var_fix);
     var_fix_out=(var_sct **)nco_free(var_fix_out);
 #endif /* !1 */
-#if 0
+#if false
     /* 20051027: Try ncwa free()'ing technique to avoid freeing dangling pointers */
     if(xtr_nbr > 0) var=nco_var_lst_free(var,xtr_nbr); 
     /* ncwa uses nco_var_lst_free() on var_prc_out because var_out has dangling pointers */
@@ -1536,7 +1536,7 @@ main(int argc,char **argv)
     var_prc=(var_sct **)nco_free(var_prc);
     var_fix=(var_sct **)nco_free(var_fix);
     var_out=(var_sct **)nco_free(var_out);
-#endif /* !0 */
+#endif /* !false */
   } /* !flg_mmr_cln */
   
   nco_exit_gracefully();
