@@ -207,6 +207,7 @@ main(int argc,char **argv)
   int att_grp_nbr;
   int att_var_nbr;
   int aux_nbr=0; /* [nbr] Number of auxiliary coordinate hyperslabs specified */
+  int brk_nbr; /* [nbr] Number of DIWG test failures */
   int cnk_map=nco_cnk_map_nil; /* [enm] Chunking map */
   int cnk_nbr=0; /* [nbr] Number of chunk sizes */
   int cnk_plc=nco_cnk_plc_nil; /* [enm] Chunking policy */
@@ -244,8 +245,13 @@ main(int argc,char **argv)
   md5_sct *md5=NULL; /* [sct] MD5 configuration */
  
   nco_bool ALPHABETIZE_OUTPUT=True; /* Option a */
+  nco_bool CHK_BND=False; /* [flg] Check coordinates for bounds attributes */
+  nco_bool CHK_CHR=False; /* [flg] Check identifiers for naughty characters */
   nco_bool CHK_MAP=False; /* [flg] Check map-file quality */
+  nco_bool CHK_MSS=False; /* [flg] Check for missing_value attribute */
   nco_bool CHK_NAN=False; /* [flg] Check for NaNs */
+  nco_bool CHK_TM=False; /* [flg] Check time variables for double precision */
+  nco_bool CHK_XTN=False; /* [flg] Check filename extension */
   nco_bool CPY_GRP_METADATA; /* [flg] Copy group metadata (attributes) */
   nco_bool EXCLUDE_INPUT_LIST=False; /* Option x */
   nco_bool EXTRACT_ALL_COORDINATES=False; /* Option c */
@@ -341,12 +347,22 @@ main(int argc,char **argv)
     {"formula_terms",no_argument,0,0}, /* [flg] Extract formula_terms variables */
     {"no_frm_trm",no_argument,0,0}, /* [flg] Do not extract formula_terms variables */
     {"no_formula_terms",no_argument,0,0}, /* [flg] Do not extract formula_terms variables */
+    {"chk_bnd",no_argument,0,0}, /* [flg] Check coordinates for bounds attributes */
+    {"check_bounds",no_argument,0,0}, /* [flg] Check coordinates for bounds attributes */
+    {"chk_chr",no_argument,0,0}, /* [flg] Check identifiers for bad characters */
+    {"check_char",no_argument,0,0}, /* [flg] Check identifiers for bad characters */
     {"chk_map",no_argument,0,0}, /* [flg] Check map-file quality */
     {"check_map",no_argument,0,0}, /* [flg] Check map-file quality */
+    {"chk_mss",no_argument,0,0}, /* [flg] Check variables+groups for missing_value attribute */
+    {"check_missing_value",no_argument,0,0}, /* [flg] Check varables+groups for missing_value attribute */
     {"chk_nan",no_argument,0,0}, /* [flg] Check file for NaNs */
     {"check_nan",no_argument,0,0}, /* [flg] Check file for NaNs */
     {"nan",no_argument,0,0}, /* [flg] Check file for NaNs */
     {"NaN",no_argument,0,0}, /* [flg] Check file for NaNs */
+    {"chk_tm",no_argument,0,0}, /* [flg] Check time variables for double precision */
+    {"check_extension",no_argument,0,0}, /* [flg] Check time variables for double precision */
+    {"chk_xtn",no_argument,0,0}, /* [flg] Check filename extension */
+    {"check_extension",no_argument,0,0}, /* [flg] Check filename extension */
     {"clean",no_argument,0,0}, /* [flg] Clean memory prior to exit */
     {"mmr_cln",no_argument,0,0}, /* [flg] Clean memory prior to exit */
     {"drt",no_argument,0,0}, /* [flg] Allow dirty memory on exit */
@@ -673,8 +689,13 @@ main(int argc,char **argv)
         dt_fmt=strtoul(optarg,&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
       } /* !dt_fmt */
       if(!strcmp(opt_crr,"calendar") || !strcmp(opt_crr,"cln_lgb") || !strcmp(opt_crr,"prn_cln_lgb") || !strcmp(opt_crr,"prn_lgb") || !strcmp(opt_crr,"timestamp")) PRN_CLN_LGB=True; /* [flg] Print UDUnits-formatted calendar dates/times human-legibly */
+      if(!strcmp(opt_crr,"chk_bnd") || !strcmp(opt_crr,"check_bounds")) CHK_BND=True; /* [flg] Check coordinates for bounds attributes */
+      if(!strcmp(opt_crr,"chk_chr") || !strcmp(opt_crr,"check_char")) CHK_CHR=True; /* [flg] Check identifiers for bad characters */
       if(!strcmp(opt_crr,"chk_map") || !strcmp(opt_crr,"check_map")) CHK_MAP=True; /* [flg] Check map-file quality */
+      if(!strcmp(opt_crr,"chk_mss") || !strcmp(opt_crr,"check_missing_value")) CHK_MSS=True; /* [fnc] Check variables+groups for missing_value attribute */
       if(!strcmp(opt_crr,"chk_nan") || !strcmp(opt_crr,"check_nan") || !strcmp(opt_crr,"nan") || !strcmp(opt_crr,"NaN")) CHK_NAN=True; /* [flg] Check for NaNs */
+      if(!strcmp(opt_crr,"chk_tm") || !strcmp(opt_crr,"check_time_double")) CHK_TM=True; /* [flg] Check time variables for double precision */
+      if(!strcmp(opt_crr,"chk_xtn") || !strcmp(opt_crr,"check_extension")) CHK_XTN=True; /* [flg] Check filename extension */
       if(!strcmp(opt_crr,"cnk_byt") || !strcmp(opt_crr,"chunk_byte")){
         cnk_sz_byt=strtoul(optarg,&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
         if(*sng_cnv_rcd) nco_sng_cnv_err(optarg,"strtoul",sng_cnv_rcd);
@@ -821,7 +842,7 @@ main(int argc,char **argv)
         flg_rgr=True;
 	rgr_map=(char *)strdup(optarg);
       } /* endif rgr_map */
-      if(!strcmp(opt_crr,"hrz_fl") || !strcmp(opt_crr,"hrz_crd") || !strcmp(opt_crr,"rgr_hrz")){
+      if(!strcmp(opt_crr,"hrz_fl") || !strcmp(opt_crr,"hrz_s1d") || !strcmp(opt_crr,"hrz_crd")){
 	flg_s1d=flg_rgr=True;
 	rgr_hrz=(char *)strdup(optarg);
       } /* !hrz_fl */
@@ -1063,7 +1084,7 @@ main(int argc,char **argv)
       goto close_and_free; 
       break;
      case '?': /* Question mark means unrecognized option, print proper usage then EXIT_FAILURE */
-      (void)fprintf(stdout,"%s: ERROR in command-line syntax/options. Missing or unrecognized option. Please reformulate command accordingly.\n",nco_prg_nm_get());
+      (void)fprintf(stdout,"%s: ERROR in command-line syntax/options. Missing or unrecognized option. Please reformulate command or upgrade NCO as appropriate.\n",nco_prg_nm_get());
       (void)nco_usg_prn();
       nco_exit(EXIT_FAILURE);
       break;
@@ -1072,7 +1093,7 @@ main(int argc,char **argv)
       nco_exit(EXIT_FAILURE);
       break;
     default: /* Print proper usage */
-      (void)fprintf(stdout,"%s ERROR in command-line syntax/options. Please reformulate command accordingly.\n",nco_prg_nm_get());
+      (void)fprintf(stdout,"%s ERROR in command-line syntax/options. Please reformulate command or upgrade NCO as appropriate.\n",nco_prg_nm_get());
       (void)nco_usg_prn();
       nco_exit(EXIT_FAILURE);
       break;
@@ -1131,11 +1152,11 @@ main(int argc,char **argv)
   /* Make sure file is on local system and is readable or die trying */
   fl_in=nco_fl_mk_lcl(fl_in,fl_pth_lcl,HPSS_TRY,&FL_RTR_RMT_LCN);
   fl_in_dpl=strdup(fl_in);
-#ifdef WIN32
-  const char sls_chr='\\';   /* [chr] Slash character */
-#else /* !WIN32 */
-  const char sls_chr='/';   /* [chr] Slash character */
-#endif /* !WIN32 */
+#if defined(_MSC_VER) || defined(WINOS)
+  const char sls_chr='\\'; /* [chr] Slash character */
+#else /* !WINOS */
+  const char sls_chr='/'; /* [chr] Slash character */
+#endif /* !WINOS */
   fl_in_stub=strrchr(fl_in_dpl,sls_chr);
   if(fl_in_stub) fl_in_stub++; else fl_in_stub=fl_in_dpl;
   fl_in_frg=strstr(fl_in_stub,"#mode");
@@ -1370,7 +1391,7 @@ main(int argc,char **argv)
 
     nco_bool ALPHA_BY_FULL_GROUP=False; /* [flg] Print alphabetically by full group */
     nco_bool ALPHA_BY_STUB_GROUP=True; /* [flg] Print alphabetically by stub group */
-    char *sfx_ptr;
+    char *sfx_ptr; /* [sng] Filename extension/suffix, if any */
 
     /* Update all GTT dimensions with hyperslabbed size */
     (void)nco_dmn_trv_msa_tbl(in_id,rec_dmn_nm,trv_tbl);   
@@ -1496,18 +1517,50 @@ main(int argc,char **argv)
       
     }else{ 
 
+      /* Begin DIWG tests */
+      if(CHK_BND){
+	/* Check coordinates for bounds attributes */
+        brk_nbr=nco_chk_bnd(in_id,trv_tbl);
+	if(brk_nbr) exit(EXIT_FAILURE); else nco_exit(EXIT_SUCCESS);
+      } /* !CHK_BND */
+
+      if(CHK_CHR){
+	/* Check identifiers for naughty characters */
+        brk_nbr=nco_chk_chr(in_id,trv_tbl);
+	if(brk_nbr) exit(EXIT_FAILURE); else nco_exit(EXIT_SUCCESS);
+      } /* !CHK_CHR */
+
+      if(CHK_MSS){
+	/* Check variables+groups for missing_value attribute */
+        brk_nbr=nco_chk_mss(in_id,trv_tbl);
+	if(brk_nbr) exit(EXIT_FAILURE); else nco_exit(EXIT_SUCCESS);
+      } /* !CHK_MSS */
+
+      if(CHK_NAN){
+	/* Check floating-point fields for NaNs */
+        brk_nbr=nco_chk_nan(in_id,trv_tbl);
+	if(brk_nbr) exit(EXIT_FAILURE); else nco_exit(EXIT_SUCCESS);
+      } /* !CHK_NAN */
+
+      if(CHK_TM){
+	/* Check that time variables are double precision */
+        brk_nbr=nco_chk_tm(in_id,trv_tbl);
+	if(brk_nbr) exit(EXIT_FAILURE); else nco_exit(EXIT_SUCCESS);
+      } /* !CHK_TM */
+
+      if(CHK_XTN){
+	/* Check filename extension */
+        brk_nbr=nco_chk_xtn(in_id,fl_in,fl_in_fmt);
+	if(brk_nbr) exit(EXIT_FAILURE); else nco_exit(EXIT_SUCCESS);
+      } /* !CHK_XTN */
+      /* End DIWG tests */
+
       if(CHK_MAP){
 	/* Check map-file quality */
 	nco_map_chk(fl_in,flg_area_wgt,flg_frac_b_nrm);
         goto close_and_free;
       } /* !CHK_MAP */
 
-      if(CHK_NAN){
-	/* Check floating-point fields for NaNs */
-        nco_chk_nan(in_id,trv_tbl);
-        goto close_and_free;
-      } /* !CHK_NAN */
-
       /* New file dump format(s) developed 201307 for CDL, JSN, SRM, TRD, XML */
       if(PRN_SRM){
 	/* Stream printing is pre-alpha. Great project for volunteers! */
