@@ -678,6 +678,8 @@ nco_cln_cnv_mk /* [fnc] UDUnits2 create custom converter */
      then NCO will report that the UDUnits2 library has failed to initialize.
      To fix this, export the location of the UDUnits2 XML database file udunits2.xml to the shell, with, e.g.:
      export UDUNITS2_XML_PATH='/opt/local/share/udunits/udunits2.xml'
+     export UDUNITS2_XML_PATH='/opt/homebrew/share/udunits/udunits2.xml'
+     export UDUNITS2_XML_PATH="${HOME}/share/udunits/udunits2.xml"
      One can then invoke (without recompilation) NCO again, and UDUNITS2 should work. */
   if(nco_dbg_lvl_get() >= nco_dbg_vrb) ut_set_error_message_handler(ut_write_to_stderr); else ut_set_error_message_handler(ut_ignore);
   ut_sys=ut_read_xml(NULL);
