@@ -38,6 +38,7 @@
 #include "nco_grp_trv.h" /* Group traversal */
 #include "nco_mmr.h" /* Memory management */
 #include "nco_msa.h" /* Multi-slabbing algorithm */
+#include "nco_ppc.h" /* Precision-Preserving Compression */
 #include "nco_prn.h" /* Print variables, attributes, metadata */
 #include "nco_var_lst.h" /* Variable list utilities */
 #include "nco_cnv_csm.h" /* CCM/CCSM/CF conventions */
@@ -46,18 +47,44 @@
 typedef struct {
   int grp_nbr; /* [nbr] Number of items in stack = number of elements in grp_id array */
   int *grp_id; /* [ID] Group ID */
-} grp_stk_sct; 
+} grp_stk_sct;
 
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
 
-void
-nco_chk_nan                           /* [fnc] Check file for NaNs */
-(const int nc_id,                     /* I [ID] netCDF input file ID */
- const trv_tbl_sct * const trv_tbl);   /* I [sct] GTT (Group Traversal Table) */
+int /* O [nbr] Number of naughty coordinates */
+nco_chk_bnd /* [fnc] Check coordinates for bounds attributes */
+(const int nc_id, /* I [ID] netCDF input file ID */
+ const trv_tbl_sct * const trv_tbl); /* I [sct] GTT (Group Traversal Table) */
 
-  nm_id_sct *                           /* O [sct] Extraction list */  
+int /* O [nbr] Number of CF non-compliant identifiers */
+nco_chk_chr /* [fnc] Check identifiers for NUG-non-compliant characters */
+(const int nc_id, /* I [ID] netCDF input file ID */
+ const trv_tbl_sct * const trv_tbl); /* I [sct] GTT (Group Traversal Table) */
+
+int /* O [nbr] Number of naughty attributes */
+nco_chk_mss /* [fnc] Check variables+groups for missing_value attribute */
+(const int nc_id, /* I [ID] netCDF input file ID */
+ const trv_tbl_sct * const trv_tbl); /* I [sct] GTT (Group Traversal Table) */
+
+int /* O [nbr] Number of variables with NaN */
+nco_chk_nan /* [fnc] Check file for NaNs */
+(const int nc_id, /* I [ID] netCDF input file ID */
+ const trv_tbl_sct * const trv_tbl); /* I [sct] GTT (Group Traversal Table) */
+
+int /* O [nbr] Number of naughty time variables */
+nco_chk_tm  /* [fnc] Check that time variables are double precision */
+(const int nc_id, /* I [ID] netCDF input file ID */
+ const trv_tbl_sct * const trv_tbl); /* I [sct] GTT (Group Traversal Table) */
+
+int /* O [nbr] Number of non-compliant extensions */
+nco_chk_xtn /* [fnc] Check filename extension */
+(const int nc_id, /* I [ID] netCDF input file ID */
+ const char * const fl_in, /* I [sng] Filename */
+ const int fl_in_fmt); /* I [enm] Input file format */
+
+nm_id_sct *                           /* O [sct] Extraction list */  
 nco_trv_tbl_nm_id                     /* [fnc] Create extraction list of nm_id_sct from traversal table */
 (const int nc_id_in,                  /* I [ID] netCDF input file ID */
  const int nc_id_out,                 /* I [ID] netCDF output file ID */
