@@ -25,14 +25,15 @@
 
 /* Personal headers */
 #include "nco.h" /* netCDF Operator (NCO) definitions */
+#include "nco_ctl.h" /* Program flow control functions */
 #include "nco_mmr.h" /* Memory management */
 #include "nco_omp.h" /* OpenMP utilities */
 #include "nco_rgr.h" /* Regridding */
 #include "nco_sld.h" /* Swath-Like Data */
 #include "nco_sng_utl.h" /* String utilities */
-#include "nco_ply_lst.h"  /* polygon list functions */
-#include "nco_ply.h"     /* polygon functions */
-#include "nco_kd.h"
+#include "nco_ply_lst.h" /* Polygon list manipulation */
+#include "nco_ply.h" /* Polygon structure & utilities */
+#include "nco_kd.h" /* K-d tree geometric data structure */
 
 #ifdef __cplusplus
 extern "C" {
@@ -87,8 +88,15 @@ extern "C" {
    nco_grd_lon_typ_enm typ_out);
   
   void
-  nco_msh_poly_lst_wrt
-  (const char *fl_out,
+  nco_msh_lon_cf /* [fnc] Adjust longitude bounds to adhere to CF conventions */
+  (const size_t grd_sz, /* I [nbr] Number of elements in single layer of source grid */
+   const long grd_crn_nbr, /* I [nbr] Maximum number of corners in source gridcell */
+   const double * const lon_ctr, /* I [dgr] Longitude centers */
+   double * const lon_crn); /* I/O [dgr] Longitude corners to be corrected */
+   
+   void
+   nco_msh_poly_lst_wrt
+   (const char *fl_out,
    poly_sct **pl_lst,
    int pl_nbr,
    nco_grd_lon_typ_enm grd_lon_typ,
@@ -165,7 +173,7 @@ extern "C" {
   (poly_sct *pl);
 
 #ifdef __cplusplus
-} /* end extern "C" */
-#endif /* __cplusplus */
+} /* !extern "C" */
+#endif /* !__cplusplus */
 
-#endif /* NCO_MAP_H */
+#endif /* !NCO_MAP_H */
