@@ -30,6 +30,7 @@
 #include "nco.h" /* netCDF Operator (NCO) definitions */
 #include "nco_cnf_typ.h" /* Conform variable types */
 #include "nco_ctl.h" /* Program flow control functions */
+#include "nco_flt.h" /* Compression filters */
 #include "nco_grp_utl.h" /* Group utilities */
 #include "nco_mmr.h" /* Memory management */
 #ifdef _MSC_VER
@@ -171,7 +172,7 @@ double val_dbl);
   
 
 #ifdef __cplusplus
-} /* end extern "C" */
+} /* !extern "C" */
 #endif /* __cplusplus */
 
 #endif /* NCO_PRN_H */
