@@ -27,6 +27,7 @@
 /* Personal headers */
 #include "nco.h" /* netCDF Operator (NCO) definitions */
 #include "nco_cnf_typ.h" /* Conform variable types nco_typ_ntg() */
+#include "nco_ctl.h" /* Program flow control functions */
 #include "nco_fl_utl.h" /* File manipulation */
 #include "nco_flt.h" /* Compression filters */
 #include "nco_mmr.h" /* Memory management */
@@ -232,6 +233,10 @@ extern "C" {
   nco_rgr_grd_sng /* [fnc] Convert grid conversion enum to string */
   (const nco_rgr_typ_enm nco_rgr_typ); /* I [enm] Grid conversion enum */
 
+  const char * /* O [sng] String describing vertical grid-type */
+  nco_vrt_grd_sng /* [fnc] Convert vertical grid-type enum to string */
+  (const nco_grd_vrt_typ_enm nco_vrt_grd_typ); /* I [enm] Vertical grid-type enum */
+
   const char * /* O [sng] String describing regridding method */
   nco_ply_dcm_sng /* [fnc] Convert regridding method enum to string */
   (const nco_rgr_mth_typ_enm nco_rgr_mth_typ); /* I [enm] Regridding method enum */
@@ -295,7 +300,7 @@ extern "C" {
    int *var_id); /* O [id] Variable ID in input/external file */
 
 #ifdef __cplusplus
-} /* end extern "C" */
+} /* !extern "C" */
 #endif /* __cplusplus */
 
 /* its here temporarily as a func prototype uses nco_mf_sct */
