@@ -150,7 +150,7 @@ void
 nco_cpy_prn(void) /* [fnc] Print copyright notice */
 {
   /* Purpose: Print copyright notice */
-  (void)fprintf(stderr,"Copyright (C) 1995--2023 Charlie Zender\n");
+  (void)fprintf(stderr,"Copyright (C) 1995--2024 Charlie Zender\n");
   (void)fprintf(stdout,"This program is part of NCO, the netCDF Operators.\nNCO is free software and comes with a BIG FAT KISS and ABSOLUTELY NO WARRANTY\nYou may redistribute and/or modify NCO under the terms of the\n3-Clause BSD License with exceptions described in the LICENSE file\nBSD: https://opensource.org/licenses/BSD-3-Clause\nLICENSE: https://github.com/nco/nco/tree/master/LICENSE\n");
 } /* end copyright_prn() */
 
@@ -208,9 +208,9 @@ const char * /* O [sng] Mnemonic that describes current NCO version */
 nco_nmn_get(void) /* [fnc] Return mnemonic that describes current NCO version */
 { 
   /* Purpose: Return mnemonic describing current NCO version
-     20191221: ncremap/ncclimo print left quote and first word of this string, so one-word strings look best 
+     20191221: ncremap/ncclimo print left quote and first word of this string, so one-word strings look best
      20200117: fixed this limitation, multi-word versions work fine */
-  return "Barbenheimer";
+  return "Shabu Shabu";
 } /* !nco_nmn_get() */
 
 void
@@ -242,7 +242,7 @@ nco_vrs_prn /* [fnc] Print NCO version */
   if(vrs_cpp[0L] == '"'){
     vrs_cpp[strlen(vrs_cpp)-1L]='\0';
     vrs_sng=vrs_cpp+1L;
-  } /* endif */
+  } /* !vrs_cpp */
 
   if(strlen(CVS_Id) > strlen("*Id*")){
     /* CVS_Id is defined */
@@ -283,5 +283,5 @@ nco_vrs_prn /* [fnc] Print NCO version */
   if(date_cvs) date_cvs=(char *)nco_free(date_cvs);
   if(vrs_rcs) vrs_rcs=(char *)nco_free(vrs_rcs);
   if(vrs_cvs) vrs_cvs=(char *)nco_free(vrs_cvs);
-} /* end nco_vrs_prn() */
+} /* !nco_vrs_prn() */
 
